# IMASEN

Programa para bajar audios de IMASEN

Para llamar a la funcion es de la siguiente manera
```python
import imasen
imasen.surveyaudios()
```

Especificar: N° de preguntas a descargar, los QuestionIdx de estas preguntas

Desarrollado por Matias Canales, 2022